@@ -9,6 +9,7 @@ import requests
 from .constants import ROW_FILTER_KEYS, ColumnTypes
 from .constants import RENAME_COLUMN, RESIZE_COLUMN, FREEZE_COLUMN, MOVE_COLUMN, MODIFY_COLUMN_TYPE, DELETE_COLUMN
 from .socket_io import connect_socket_io
+from .query import QuerySet
 
 
 def parse_headers(token):
@@ -52,7 +53,11 @@ class SeaTableAPI(object):
         self.dtable_name = None
 
     def __str__(self):
-        return 'SeaTableAPI Object [ %s ]' % self.dtable_uuid
+        return 'SeaTable Base [ %s ]' % self.dtable_uuid
+
+    def _clone(self):
+        clone = self.__class__(self.token, self.server_url)
+        return clone
 
     def auth(self, with_socket_io=False):
         """Auth to SeaTable
@@ -82,6 +87,9 @@ class SeaTableAPI(object):
     def _batch_row_server_url(self):
         return self.dtable_server_url + '/api/v1/dtables/' + self.dtable_uuid + '/batch-append-rows/'
 
+    def _batch_delete_row_server_url(self):
+        return self.dtable_server_url + '/api/v1/dtables/' + self.dtable_uuid + '/batch-delete-rows/'
+
     def _filtered_rows_server_url(self):
         return self.dtable_server_url + '/api/v1/dtables/' + self.dtable_uuid + '/filtered-rows/'
 
@@ -191,6 +199,19 @@ class SeaTableAPI(object):
         response = requests.delete(url, json=json_data, headers=self.headers)
         return parse_response(response)
 
+    def batch_delete_rows(self, table_name, row_ids):
+        """
+        :param table_name: str
+        :param row_ids: list
+        """
+        url = self._batch_delete_row_server_url()
+        json_data = {
+            'table_name': table_name,
+            'row_ids': row_ids,
+        }
+        response = requests.delete(url, json=json_data, headers=self.headers)
+        return parse_response(response)
+
     def filter_rows(self, table_name, filters, view_name=None, filter_conjunction='And'):
         """
         :param table_name: str
@@ -207,13 +228,13 @@ class SeaTableAPI(object):
         if len(filters) != len([f for f in filters if isinstance(f, dict)]):
             raise ValueError('filters invalid.')
 
-        for filter in filters:
-            for key in filter.keys():
+        for f in filters:
+            for key in f.keys():
                 if key not in ROW_FILTER_KEYS:
                     raise ValueError('filters invalid.')
 
         if filter_conjunction not in ['And', 'Or']:
-            raise ValueError('filter_conjunction invalud, filter_conjunction must be '
+            raise ValueError('filter_conjunction invalid, filter_conjunction must be '
                              '"And" or "Or"')
 
         params = {
@@ -452,7 +473,7 @@ class SeaTableAPI(object):
 
     def upload_bytes_file(self, name, content: bytes, relative_path=None, file_type=None, replace=False):
         """
-        relateive_path: relative path for upload, if None, default {file_type}s/{date of this month} eg: files/2020-09
+        relative_path: relative path for upload, if None, default {file_type}s/{date of this month} eg: files/2020-09
         file_type: if relative is None, file type must in ['image', 'file'], default 'file'
         return: info dict of uploaded file
         """
@@ -492,7 +513,7 @@ class SeaTableAPI(object):
 
     def upload_local_file(self, file_path, name=None, relative_path=None, file_type=None, replace=False):
         """
-        relateive_path: relative path for upload, if None, default {file_type}s/{date of today}, eg: files/2020-09
+        relative_path: relative path for upload, if None, default {file_type}s/{date of today}, eg: files/2020-09
         file_type: if relative is None, file type must in ['image', 'file'], default 'file'
         return: info dict of uploaded file
         """
@@ -534,6 +555,22 @@ class SeaTableAPI(object):
             'url': url
         }
 
+    def filter(self, table_name, conditions='', view_name=None):
+        """
+        :param table_name: str
+        :param conditions: str
+        :return: queryset
+        """
+        base = self._clone()
+        base.auth()
+        queryset = QuerySet(base, table_name)
+        queryset.raw_rows = self.list_rows(table_name, view_name)
+        queryset.raw_columns = self.list_columns(table_name, view_name)
+        queryset.conditions = conditions
+        queryset._execute_conditions()
+        return queryset
+
+
 class Account(object):
     def __init__(self, login_name, password, server_url):
         self.login_name = login_name
@@ -543,7 +580,7 @@ class Account(object):
         self.token = None
 
     def __str__(self):
-        return 'Account Object [%s]' % (self.login_name)
+        return 'SeaTable Account [ %s ]' % (self.login_name)
 
     def _get_api_token_url(self):
         return '%s/api2/auth-token/' % (self.server_url,)
